@@ -18,3 +18,9 @@
 # WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 # IN THE SOFTWARE.
+
+from __future__ import absolute_import
+
+# Import this module so that users can simply import the top-level module. Once
+# imported, boto will pick up our subclasses of AuthHandler.
+from oauth2_plugin import oauth2_plugin
